==> vz-recommender-0.4.5.tar.gz: vz-recommender-0.4.5/README.md <==
# Personalization AI (PZAI)

![Python Versions](https://img.shields.io/badge/python-3.6%7C3.7-brightgreen)
![PyTorch Versions](https://img.shields.io/badge/pytorch-1.10.0-brightgreen)
![Ray Versions](https://img.shields.io/badge/ray-1.13.0-brightgreen)
![PyPI Version](https://badge.fury.io/py/vz_recommender.svg)

## More About Personalization AI
Personalization AI(PZAI) is an centralized personalization framework for building end to end large-scale personalization solutions. The use cases developed on top of personalization AI can seamless integrate to Verizon personalization ecosystem, scale out to the Verizon AI infrastructure, and measurement framework in the production environment.

Personalization AI provides end-to-end support for:
- Big Data ETL: feature extraction pipeline which matches same pipeline running in realtime environment
- Model Training: large scale distributed model training on Ray and Pytorch Lightning
- Serving: High performance model serving on seldon-core and Ray, support Python/Java/Scala API

PZAI adopted the latest pathway learning architecture, details can be found in the following diagram:
<img src="./recommender/product_ranking/VCG Forward - AID Initiatives.png" width="800" />


## Communication
* GitLab Issues: Please use gitlab issues to submit bug reports, feature requests, install issues, RFCs, thoughts, etc. 
* Slack: We have slack channels host a primary audience of moderate to experienced personalization engineers for general discussions and collaboration. If you need a slack invite, please contact luyang.wang@verizon.com

## Releases 
PZAI plans to adopt a 90-day release cycle (major releases), currently working in progress. Please let us know if you encounter a bug by [filing an issue](https://gitlab.verizon.com/aiml_ds/personalization-ai/-/issues).
We appreciate all contributions. If you plan to contribute new features, bug fixes, or extensions to the core, please first open an issue and discuss the feature with us.
Sending a PR without discussion might end up resulting in a rejected PR because we might be taking the core in a different direction than you might be aware of.

==> vz-recommender-0.4.7.tar.gz: vz-recommender-0.4.7/README.md <==
# Personalization AI (PZAI)

![Python Versions](https://img.shields.io/badge/python-3.6%7C3.7-brightgreen)
![PyTorch Versions](https://img.shields.io/badge/pytorch-1.10.0-brightgreen)
![Ray Versions](https://img.shields.io/badge/ray-1.13.0-brightgreen)
![PyPI Version](https://badge.fury.io/py/vz_recommender.svg)

## More About Personalization AI
Personalization AI(PZAI) is an centralized personalization framework for building end to end large-scale search & recommender systems. The use cases developed on top of personalization AI can seamless integrate to Verizon personalization ecosystem, scale out to the Verizon AI infrastructure, and measurement framework in the production environment.

Personalization AI provides end-to-end support for:
- Big Data ETL: feature extraction pipeline which matches same pipeline running in realtime environment
- Model Training: large scale distributed model training on Ray and Pytorch Lightning
- Serving: High performance model serving on seldon-core and Ray, support Python/Java/Scala API
- App: Full platform search & LLM application developed in Flutter

PZAI adopted the latest pathway learning architecture, details can be found in the following diagram:
<img src="./search_reco/product_ranking/VCG Forward - AID Initiatives.png" width="800" />


## Communication
* GitLab Issues: Please use gitlab issues to submit bug reports, feature requests, install issues, RFCs, thoughts, etc. 
* Slack: We have slack channels host a primary audience of moderate to experienced personalization engineers for general discussions and collaboration. If you need a slack invite, please contact luyang.wang@verizon.com

## Releases 
PZAI plans to adopt a 90-day release cycle (major releases), currently working in progress. Please let us know if you encounter a bug by [filing an issue](https://gitlab.verizon.com/aiml_ds/personalization-ai/-/issues).
We appreciate all contributions. If you plan to contribute new features, bug fixes, or extensions to the core, please first open an issue and discuss the feature with us.
Sending a PR without discussion might end up resulting in a rejected PR because we might be taking the core in a different direction than you might be aware of.
